@@ -1,7 +1,7 @@
 import re
 
-from utils.assert_string import assert_string
-from alpha import alpha
+from .utils.assert_string import assert_string
+from .alpha import alpha
 
 def is_alpha(input, locale = 'en-US', options = {}):
     assert_string(input)
@@ -14,7 +14,6 @@ def is_alpha(input, locale = 'en-US', options = {}):
             pattern = "[{}]".format(re.escape(ignore))
             
             string = re.sub(pattern, '', string)
-            print(pattern)
         else:
             raise Exception('ignore should be instance of a String or RegExp')
 
